@@ -16,15 +16,17 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 extern "C" {
+#ifndef strerror
   char *strerror(int);
+#endif
 #ifndef __BORLANDC__
   const char *itoa(int);
   const char *iftoa(int, int);
 #endif /* __BORLANDC__ */
-};
+}
 
 #ifdef STDLIB_H_DECLARES_GETOPT
 #include <stdlib.h>
@@ -34,7 +36,7 @@ extern "C" {
 #include <unistd.h>
 #else /* not UNISTD_H_DECLARES_GETOPT */
 extern "C" {
-  int getopt(int, char **, const char *);
+  int getopt(int, char *const *, const char *);
 }
 #endif /* not UNISTD_H_DECLARES_GETOPT */
 
@@ -53,6 +55,18 @@ int is_prime(unsigned);
 
 FILE *xtmpfile();
 
+#ifndef STDIO_H_DECLARES_POPEN
+
+extern "C" { FILE *popen(const char *, const char *); }
+
+#endif /* not STDIO_H_DECLARES_POPEN */
+
+#ifndef STDIO_H_DECLARES_PCLOSE
+
+extern "C" { int pclose (FILE *); }
+
+#endif /* not STDIO_H_DECLARES_PCLOSE */
+
 int interpret_lf_args(const char *p);
 
 extern char illegal_char_table[];
@@ -91,6 +105,12 @@ inline int illegal_input_char(int c)
 
 #define INT_DIGITS 10
 
+#ifdef PI
+#undef PI
+#endif
+
+const double PI = 3.14159265358979323846;
+
 /* ad_delete deletes an array of objects with destructors;
 a_delete deletes an array of objects without destructors */
 
