@@ -15,7 +15,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #include "ptable.h"
 #include "errarg.h"
@@ -44,7 +44,8 @@ static const unsigned table_sizes[] = {
 
 unsigned next_ptable_size(unsigned n)
 {
-  for (const unsigned *p = table_sizes; *p <= n; p++)
+  const unsigned *p;  
+  for (p = table_sizes; *p <= n; p++)
     if (*p == 0)
       fatal("cannot expand table");
   return *p;
